@@ -1,6 +1,6 @@
 #   BAREOS - Backup Archiving REcovery Open Sourced
 #
-#   Copyright (C) 2020-2020 Bareos GmbH & Co. KG
+#   Copyright (C) 2015-2021 Bareos GmbH & Co. KG
 #
 #   This program is Free Software; you can redistribute it and/or
 #   modify it under the terms of version three of the GNU Affero General Public
@@ -17,7 +17,12 @@
 #   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 #   02110-1301, USA.
 
-# __all__ = [ "bconsole" ]
+"""
+Bareos utility classes.
+"""
+
 from bareos.util.bareosbase64 import BareosBase64
 from bareos.util.password import Password
 from bareos.util.path import Path
+
+__all__ = ["BareosBase64", "Password", "Path"]
